@@ -51,6 +51,7 @@ sub descend
 	my $countcase = $dat{countcase}; 
 	my $countblock = $dat{countblock}; 
 	my %dirfiles = %{ $dat{dirfiles} }; 
+	my %datastruc = %{ $dat{datastruc} }; ######
 		
 	$configfile = $main::configfile; 
 	@varinumbers = @main::varinumbers; 
@@ -153,7 +154,6 @@ sub descend
 	my @backvalues = @{ $d{backvalues} }; say $tee "IN DESCENT \@backvalues " . dump(@backvalues);
 	my @sweeps = @{ $d{sweeps} }; say $tee "dump(\@sweeps): " . dump(@sweeps);
 	my @sourcesweeps = @{ $d{sourcesweeps} }; say $tee "dump(\@sourcesweeps): " . dump(@sourcesweeps);
-	#eval($getparshere);
 	
 	my $counthold = 0;
 	
@@ -166,7 +166,8 @@ sub descend
 	my $from = Sim::OPT::getline($toitem); 
 	my %varnums = Sim::OPT::getcase(\@varinumbers, $countcase); 
 	my %mids = Sim::OPT::getcase(\@miditers, $countcase); 
-	#eval($getfly);
+
+	my $word = ( "_", @blockelts ); ###NEW
 	
 	my $stepsvar = Sim::OPT::getstepsvar($countvar, $countcase, \@varinumbers); 
 	my $varnumber = $countvar; 
@@ -567,6 +568,7 @@ sub descend
 		#}
 		
 		push( @backvalues, [ $winnerline, $winnerval ] );  say $tee "OBTAINED--->\@backvalues " . dump( @backvalues );
+		push( @{ $datastruc{$word} }, $winnerline );  say $tee "OBTAINED--->\@{ \$datastruc{\$word} } " . dump( @{ $datastruc{$word} } );
 		say $tee "\$sourcesweeps[ \$countcase ][ \$countblock ][0] " . dump( $sourcesweeps[ $countcase ][ $countblock ][0] );
 				
 		
