@@ -1,7 +1,7 @@
 package Sim::OPT::Parcoord3d;
 # Copyright (C) 2015 by Gian Luca Brunetti and Politecnico di Milano.
 # This is Sim::OPT::Parcoord3d, a program that can receive as input the data for a bi-dimensional parallel coordinate plot in cvs format to produce as output an Autolisp file that can be used from Autocad or Intellicad-based 3D CAD programs to obtain 3D parallel coordinate plots.
-# This is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
+# This is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 2.
 
 use v5.14;
 # use v5.20;
@@ -26,7 +26,7 @@ use Data::Dumper;
 #$Data::Dumper::Terse  = 1;
 use Data::Dump qw(dump);
 use feature 'say';
-no strict;
+no strict; 
 no warnings;
 
 use Sim::OPT;
@@ -36,13 +36,12 @@ use Sim::OPT::Report;
 use Sim::OPT::Descend;
 use Sim::OPT::Takechance;
 
-
 our @ISA = qw(Exporter); # our @adamkISA = qw(Exporter);
 #%EXPORT_TAGS = ( DEFAULT => [qw( &opt &prepare )]); # our %EXPORT_TAGS = ( 'all' => [ qw( ) ] );
 #@EXPORT_OK   = qw(); # our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 @EXPORT = qw( parcoord3d ); # our @EXPORT = qw( );
-$VERSION = '0.01.5';
+$VERSION = '0.01.3'; 
 $ABSTRACT = 'Sim::OPT::Parcoord3d is a program that can process the CSV data for a bi-dimensional parallel coordinate plot and output an Autolisp file for a 3D parallel coordinate plot.';
 
 #########################################################################################
@@ -56,30 +55,30 @@ sub parcoord3d
 		$tofile = $main::tofile;
 		#$tee = new IO::Tee(\*STDOUT, ">>$tofile"); # GLOBAL ZZZ
 		say $tee "\n#Now in Sim::OPT::Takechance.\n";
-		$configfile = $main::configfile;
-		@sweeps = @main::sweeps;
-		@sourcesweeps = @main::sourcesweeps;
-		@varnumbers = @main::varnumbers; say $tee "dump(\@varnumbers): " . dump(@varnumbers);
-		@miditers = @main::miditers;
-		@rootnames = @main::rootnames;
-		%vals = %main::vals;
-
-		$mypath = $main::mypath;
-		$exeonfiles = $main::exeonfiles;
-		$generatechance = $main::generatechance;
+		$configfile = $main::configfile; 
+		@sweeps = @main::sweeps; 
+		@sourcesweeps = @main::sourcesweeps; 
+		@varinumbers = @main::varinumbers; say $tee "dump(\@varinumbers): " . dump(@varinumbers);
+		@mediumiters = @main::mediumiters;
+		@rootnames = @main::rootnames; 
+		%vals = %main::vals; 
+		
+		$mypath = $main::mypath;  
+		$exeonfiles = $main::exeonfiles; 
+		$generatechance = $main::generatechance; 
 		$file = $main::file;
 		$preventsim = $main::preventsim;
-		$fileconfig = $main::fileconfig;
+		$fileconfig = $main::fileconfig; 
 		$outfile = $main::outfile;
 		$target = $main::target;
-
+		
 		$convertfile = $main::convertfile;
-		$pick = $main::pick;
+		$pick = $main::pick; 
 		$numof_pars = $main::numof_pars;
-		$xspacing = $main::xspacing;
+		$xspacing = $main::xspacing; 
 		$yspacing = $main::yspacing;
 		$zspacing = $main::zspacing;
-		$ob_column = $main::ob_column;
+		$ob_column = $main::ob_column; 
 		$numof_layers = $main::numof_layers;
 		$otherob_column = $main::otherob_column;
 		$cut_column = $main::cut_column;
@@ -105,7 +104,7 @@ sub parcoord3d
 	close CONVERTFILE;
 
 	if ($pick)
-	{
+	{ 
 		$convertedfile = "$convertfile" . "filtered.csv";
 		open ( CONVERTEDFILE, ">$convertedfile" ) or die;
 		my $countline = 0;
@@ -114,16 +113,16 @@ sub parcoord3d
 			print CONVERTEDFILE "$lines[$countline]";
 			$countline++;
 		}
-
+	
 		$countline = ($#lines - $pick) ;
-		while ( $countline  < $#lines )
+		while ( $countline  < $#lines ) 
 		{
 			print CONVERTEDFILE "$lines[$countline]";
 			$countline++;
 		}
 		close CONVERTEDFILE;
-
-		open ( CONVERTEDFILE, "$convertedfile" );
+	
+		open (CONVERTEDFILE, "$convertedfile" );
 		@lines = <CONVERTEDFILE>;
 		close CONVERTEDFILE;
 	}
@@ -134,7 +133,7 @@ sub parcoord3d
 	sub makedata
 	{
 		my $swap = shift; my @lines = @$swap;
-
+	
 		my $countline = 0;
 		foreach my $line (@lines)
 		{
@@ -150,14 +149,14 @@ sub parcoord3d
 			{
 				$ob_fun = $rowelts[$#rowelts];
 			}
-
+		
 			my $otherob_fun = $rowelts[$otherob_column];
 			if ( $otherob_fun =~ /-/ )
 			{
 				my @thesedata = split( /-/ , $otherob_fun );
 				$otherob_fun = $thesedata[1];
 			}
-
+		
 			my $countvar = 0;
 			foreach my $rowelt (@rowelts)
 			{
@@ -166,7 +165,7 @@ sub parcoord3d
 					if ( $rowelt =~ /-/ )
 					{
 						my @vardata = split( /-/ , $rowelt );
-
+						
 						push ( @linedata, [ @vardata ] );
 					}
 					else
@@ -175,7 +174,7 @@ sub parcoord3d
 					}
 					$countvar++;
 				}
-			}
+			}		
 			push ( @newdata, [ @linedata, $otherob_fun, $ob_fun ] );
 			$countline++;
 		}
@@ -190,7 +189,7 @@ sub parcoord3d
 		{
 			chomp($line);
 			my @elts = @{$line};
-
+		
 			my $elm1 = pop(@elts);
 			push ( @obfun, $elm1 );
 			my $elm2 = pop(@elts);
@@ -203,14 +202,14 @@ sub parcoord3d
 				my $value = $pair[1];
 				push ( @{$pars[$count]}, $value );
 				$count++;
-			}
+			}	
 		}
-
+	
 		$maxobfun = max(@obfun);
-		$minobfun = min(@obfun);
+		$minobfun = min(@obfun);	
 		$maxotherobfun = max(@otherobfun);
 		$minotherobfun = min(@otherobfun);
-
+	
 		$countel = 0;
 		foreach my $e (@obfun)
 		{
@@ -224,7 +223,7 @@ sub parcoord3d
 			}
 			$countel++;
 		}
-
+	
 		my $countel2 = 0;
 		foreach my $e (@otherobfun)
 		{
@@ -269,13 +268,13 @@ sub parcoord3d
 		my $case_per_layer = ( scalar(@newdata) / $numof_layers );
 		$countcase = 0;
 		foreach my $el ( @{$pars[0]} )
-		{
-			my @provbowl;
+		{	
+			my @provbowl;	
 			my $scaled_zvalue = ( ( $newdata[$countcase][($#{$newdata[$countcase]}-1)] - $minotherobfun ) / ( $maxotherobfun - $minotherobfun ) );
 			my $countvar = 0;
 			while ($countvar < $numof_pars)
 			{
-				my $layer_num = ( int( $countcase / $case_per_layer ) + 1) ;
+				my $layer_num = ( int( $countcase / $case_per_layer ) + 1) ; 
 				my $scaled_xvalue = ( $countvar / $scale_xspacing );
 				my $scaled_yvalue = ( ( $pars[$countvar][$countcase] - $minpars[$countvar] ) / ( $maxpars[$countvar] - $minpars[$countvar] ) );
 				$scaled_yvalue = ($scaled_yvalue * $yspacing);
@@ -288,7 +287,7 @@ sub parcoord3d
 				{
 					push (@provbowl, [ $scaled_xvalue, $scaled_yvalue, 0, $layer_num ] );
 				}
-				$countvar++;
+				$countvar++;			
 			}
 			push (@plotdata, [ @provbowl ]);
 			$countcase++;
@@ -310,7 +309,7 @@ sub parcoord3d
 
 	sub printplotdata_pretreated
 	{
-		open ( WRITEFILE_PRETREATED, ">$writefile_pretreated") or die;
+		open (WRITEFILE_PRETREATED, ">$writefile_pretreated") or die;
 		print WRITEFILE_PRETREATED dump(@plotdata); #CONTROL!!!
 		close WRITEFILE_PREATREATED;
 	}
@@ -319,7 +318,7 @@ sub parcoord3d
 	sub solidify
 	{print "BEGUN\n";
 		my $swap = shift; my @plotdata = @$swap;
-		open ( WRITEFILE, ">$writefile") or die;
+		open (WRITEFILE, ">$writefile") or die;
 		my $countgroup = 0;
 		foreach my $e (@plotdata)
 		{
@@ -340,10 +339,10 @@ sub parcoord3d
 						my @cutelems = @elems[0..2]; # PUT ..2 IF ALSO THE THIRD AXIS HAS TO BE CHECKED FOR NON-REPETITIONS, PUT 1 OTHERWISE.
 						if (@cutelms ~~ @cutelems)
 						{
-
+							
 							$counthit++;
 							print "COUNTGROUP: $countgroup, HIT! $counthit\n";
-
+						
 							if ($counthit > 0)
 							{
 								print "COUNTHITNOW: $counthit\n";
@@ -362,9 +361,9 @@ sub parcoord3d
 								push(@newnewbag, [ nlowmult($round, $elms[0]), nlowmult($round, $elms[1]), nlowmult($round, $elms[2]), nlowmult($round, $elms[3]) ]);
 							}
 						}
-					}
+					}	
 				}
-
+			
 				$counter++
 			}
 			push( @newplotdata, [ @newnewbag ] );
@@ -391,26 +390,26 @@ sub parcoord3d
 			{
 				my @coords = @{$elt};
 				my @nextcoords = @{$elts[$countpar+1]};
-
-
+				
+				
 				my @newcoords;
 				push( @newcoords, [ @coords ] );
 				push( @newcoords, [ ($coords[0] - ($yspacing * $offset ) ) , $coords[1] , $coords[2], $coords[3] ] );
 				push( @newcoords, [ ($coords[0] - ($yspacing * $offset ) ) , $coords[1] , ( $coords[2] - ($yspacing * $offset ) ) , $coords[3] ] );
 				push( @newcoords, [ $coords[0], $coords[1] , ( $coords[2] - ($yspacing * $offset ) ) , $coords[3] ] );
 				push( @newplotdatabottom, [ @newcoords ] );
-
-
+				
+			
 				my @newcoords;
 				unless ($countpar == $#elts)
-				{
+				{			
 					push( @newcoords, [ @coords ] );
 					push( @newcoords, [ ($coords[0] - ($yspacing * $offset ) ) , $coords[1] , $coords[2], $coords[3] ] );
 					push( @newcoords, [ ($nextcoords[0] - ($yspacing * $offset ) ) , $nextcoords[1] , $nextcoords[2], $nextcoords[3] ] );
 					push( @newcoords, [ @nextcoords] );
 					push( @newplotdatafront, [ @newcoords ] );
 				}
-
+				
 
 				my @newcoords;
 				unless ($countpar == $#elts)
@@ -421,7 +420,7 @@ sub parcoord3d
 					push( @newcoords, [ ($nextcoords[0] - ($yspacing * $offset ) ) , $nextcoords[1] , $nextcoords[2], $nextcoords[3] ] );
 					push( @newplotdataleft, [ @newcoords ] );
 				}
-
+				
 
 				my @newcoords;
 				unless ($countpar == $#elts)
@@ -432,7 +431,7 @@ sub parcoord3d
 					push( @newcoords, [ ($nextcoords[0] - ($yspacing * $offset ) ) , $nextcoords[1] , ( $nextcoords[2] - ($yspacing * $offset ) ) , $nextcoords[3] ] );
 					push( @newplotdataback, [ @newcoords ] );
 				}
-
+				
 
 				my @newcoords;
 				unless ($countpar == $#elts)
@@ -443,11 +442,11 @@ sub parcoord3d
 					push( @newcoords, [ $nextcoords[0], $nextcoords[1] , ( $nextcoords[2] - ($yspacing * $offset ) ) , $nextcoords[3] ] );
 					push( @newplotdataright, [ @newcoords ] );
 				}
-
-
+				
+	
 				$countpar++;
 			}
-
+		
 			if (@newplotdatafront)
 			{
 				push(@newnewdata, @newplotdatabottom , @newplotdatafront,  @newplotdataleft, @newplotdataback, @newplotdataright );
@@ -457,7 +456,7 @@ sub parcoord3d
 				push(@newnewdata, @newplotdatabottom );
 			}
 
-
+			
 			$countgroup++;
 		}
 		print TRANSITIONAL dump(@newnewdata);
@@ -468,7 +467,7 @@ sub parcoord3d
 
 	sub writelisp
 	{
-		open( LISPFILE, ">$lispfile");
+		open(LISPFILE, ">$lispfile");
 		my $counter = 1;
 		foreach my $colour (@layercolours)
 		{
@@ -508,7 +507,7 @@ The objective function to be represented through colours in the parallel coordin
 
 "Sim::OPT::Parcoord3d" can be called from Sim::OPT or directly from the command line (after issuing < re.pl > and < use Sim::OPT::Parcoord3d >) with the command < parcoord3d your_configuration_file.pl >.
 
-The variables to be specified in the configuration file are described in the comments in the "Sim::OPT" configuration file included in the "examples" folder in this distribution ("des.pl", for instance - then search for "Parcoord3d").
+The variables to be specified in the configuration file are described in the comments in the "Sim::OPT" configuration file included in the "examples" folder in this distribution ("des.pl", for instance - then search for "Parcoord3d"). 
 
 
 =head2 EXPORT
@@ -525,7 +524,10 @@ Gian Luca Brunetti, E<lt>gianluca.brunetti@polimi.itE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015-2016 by Gian Luca Brunetti and Politecnico di Milano. This is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
+Copyright (C) 2015-2016 by Gian Luca Brunetti and Politecnico di Milano. This is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 2 or later.
 
 
 =cut
+
+
+
